BleDevice class

Constructors

BleDevice({required String name, int? rssi, String? mac, String? uuid})
BleDevice.fromJson(Map json)

Properties

hashCode int
The hash code for this object.
no setterinherited
mac String?
getter/setter pair
name String
getter/setter pair
rssi int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String?
getter/setter pair

Methods

fromJson(String str) BleDevice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited