MethodChannelBlePlugin class

An implementation of BlePluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBlePlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(BleDevice device) Future<void>
override
disconnect() Future<void>
override
getConnectedDevice() Future<String?>
override
getPlatformVersion() Future<String?>
override
isAvailable() Future<bool>
override
isConnected() Future<bool>
override
isEnable() Future<bool>
override
isScanning() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendUint8Command(Uint8List command) Future<void>
override
sendUint8TextCommand(String command) Future<void>
override
startScanBluetooth() Future<void>
override
stopScanBluetooth() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited