BlePluginPlatform class abstract

Create by kaka on 2024/2/26 0016

Inheritance
  • Object
  • PlatformInterface
  • BlePluginPlatform
Implementers

Constructors

BlePluginPlatform()
Constructs a BlePluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(BleDevice device) Future<void>
disconnect() Future<void>
getConnectedDevice() Future<String?>
getPlatformVersion() Future<String?>
isAvailable() Future<bool>
isConnected() Future<bool>
isEnable() Future<bool>
isScanning() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendUint8Command(Uint8List command) Future<void>
sendUint8TextCommand(String command) Future<void>
startScanBluetooth() Future<void>
stopScanBluetooth() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BlePluginPlatform
The default instance of BlePluginPlatform to use.
getter/setter pair