BlePluginWeb class

A web implementation of the BlePluginPlatform of the BlePlugin plugin.

Inheritance

Constructors

BlePluginWeb()
Constructs a BlePluginWeb

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(BleDevice device) Future<void>
inherited
disconnect() Future<void>
inherited
getConnectedDevice() Future<String?>
inherited
getPlatformVersion() Future<String?>
Returns a String containing the version of the platform.
override
isAvailable() Future<bool>
inherited
isConnected() Future<bool>
inherited
isEnable() Future<bool>
inherited
isScanning() Future<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendUint8Command(Uint8List command) Future<void>
inherited
sendUint8TextCommand(String command) Future<void>
inherited
startScanBluetooth() Future<void>
inherited
stopScanBluetooth() Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void