EventChannelConstant class
Create by kaka on 2024/2/26 0016
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- BLUETOOTHOFF → const int
- BLUETOOTHON → const int
- DATA_RECEIVED → const int
- FOUND_DEVICE → const int
- STATE_CONNECTED → const int
- STATE_DISCONNECTED → const int
- STATE_FAILCONNECT → const int
- WRITE_END → const int
- WRITE_START → const int